set_page_cache_size

Function set_page_cache_size 

pub fn set_page_cache_size(size: BytePageSize, count: usize)
Sets the maximum number of cached page allocations of page size size on the current thread.

By default fewer pages are cached for larger page sizes:

Page size4K8K16K24K32K48K64K128K256K
Pages1286464321681621

Buffers of BytePageSize::Unset are never cached, the call does nothing for it.

This setting affects only the thread on which it is called.