pub struct StorageVTable { /* private fields */ }Expand description
Functions that give Bytes access to externally owned data.
Every function receives the (addr, len) pair returned by
StorageExt::create, or by a previous clone.
Implementations
Sourceimpl StorageVTable
impl StorageVTable
Sourcepub const fn new(
as_ptr: unsafe fn(*const u8, usize) -> *const u8,
len: unsafe fn(*const u8, usize) -> usize,
clone: unsafe fn(*const u8, usize) -> Option<(*const u8, usize)>,
drop: unsafe fn(*const u8, usize),
) -> StorageVTable
pub const fn new( as_ptr: unsafe fn(*const u8, usize) -> *const u8, len: unsafe fn(*const u8, usize) -> usize, clone: unsafe fn(*const u8, usize) -> Option<(*const u8, usize)>, drop: unsafe fn(*const u8, usize), ) -> StorageVTable
Creates a vtable from its functions.
as_ptrreturns a pointer to the start of the data.lenreturns the length of the data in bytes.clonereturns the(addr, len)pair of a new handle to the same data, orNoneto make the clone copy the data instead.dropreleases the handle.
The requirements these functions must meet are listed on
StorageExt.