pub fn set_pages_cache(size: usize)👎Deprecated since 1.11.0:
the cache limit depends on the page size, use set_page_cache_size()
Sets the maximum number of cached page allocations for every page size on the current thread.
This setting affects only the thread on which it is called.