pub fn set_pages_cache(size: usize)
Sets the maximum number of cached page allocations per page size for the current thread, the default is 16.
This setting affects only the thread on which it is called.