pub struct BytePages { /* private fields */ }Implementations
Sourceimpl BytePages
impl BytePages
Sourcepub fn new(size: BytePageSize) -> Self
pub fn new(size: BytePageSize) -> Self
Creates a new BytePages with the specified page size.
The returned BytePages will be hold one page with
specified capacity.
pub fn page_size(&self) -> BytePageSize
pub fn set_page_size(&mut self, size: BytePageSize)
pub fn prepend<T>(&mut self, buf: T) -> bool
pub fn append<T>(&mut self, buf: T)
Sourcepub fn extend_from_slice(&mut self, extend: &[u8])
pub fn extend_from_slice(&mut self, extend: &[u8])
Appends the given bytes to this page object.
Tries to write the data into the current page first. If there is insufficient space, one or more new pages are allocated as needed, and the remaining data is copied into them.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn take(&mut self) -> Option<BytePage>
pub fn move_to(&mut self, pages: &mut BytePages)