BytePages

Struct BytePages 

pub struct BytePages { /* private fields */ }

Implementations

Source

impl BytePages

pub fn new(size: BytePageSize) -> Self

Creates a new BytePages with the specified page size.

The returned BytePages will be hold one page with specified capacity.

pub fn page_size(&self) -> BytePageSize

Get size of the page.

pub fn set_page_size(&mut self, size: BytePageSize)

Sets the page size for new pages.

pub fn prepend<T>(&mut self, buf: T) -> bool
where BytePage: From<T>,

Insert a page to the front of the collection.

pub fn append<T>(&mut self, buf: T)
where BytePage: From<T>,

Appends a new page to the back of the collection.

pub fn extend_from_slice(&mut self, extend: &[u8])

Appends the given bytes to this page object.

Tries to write the data into the current page first. If there is insufficient space, one or more new pages are allocated as needed, and the remaining data is copied into them.

pub fn len(&self) -> usize

Gets the total number of pages.

pub fn is_empty(&self) -> bool

Checks if the BytePages instance is empty.

pub fn num_pages(&self) -> usize

Returns the total number of pages contained in this object.

pub fn take(&mut self) -> Option<BytePage>

Returns the first page from the collection.

pub fn copy_to(&self, pages: &mut BytePages)

Copies all pages into another BytePages instance.

Depending on the underlying storage, this operation might be O(1) or could involve a memory copy.

pub fn move_to(&mut self, pages: &mut BytePages)

Moves all pages to another BytePages instance.

pub fn split_to(&mut self, at: usize) -> BytePages

Splits the buffer into two at the given index.

Afterwards, self contains elements [at, len), and the returned BytePage contains elements [0, at).

Depending on the underlying storage, this operation might be O(1) or could involve a memory copy.

pub fn split_into(&mut self, at: usize, to: &mut BytePages)

Splits the buffer, adding the resulting items to the supplied pages object.

Afterwards, self contains elements [at, len), and the supplied BytePage contains elements [0, at).

Depending on the underlying storage, this operation might be O(1) or could involve a memory copy.

pub fn freeze(&mut self) -> Bytes

Converts self into an immutable Bytes.

pub fn try_get_current_from(&mut self, pages: &mut BytePages)

pub fn with_bytes_mut<F, R>(&mut self, f: F) -> R
where F: FnOnce(&mut BytesMut) -> R,

Access current page as BytesMut object