pub struct BytePages { /* private fields */ }Implementations
Sourceimpl BytePages
impl BytePages
Sourcepub fn new(size: BytePageSize) -> Self
pub fn new(size: BytePageSize) -> Self
Creates a new BytePages with the specified page size.
The returned BytePages will be hold one page with
specified capacity.
Sourcepub fn page_size(&self) -> BytePageSize
pub fn page_size(&self) -> BytePageSize
Get size of the page.
Sourcepub fn set_page_size(&mut self, size: BytePageSize)
pub fn set_page_size(&mut self, size: BytePageSize)
Sets the page size for new pages.
Sourcepub fn extend_from_slice(&mut self, extend: &[u8])
pub fn extend_from_slice(&mut self, extend: &[u8])
Appends the given bytes to this page object.
Tries to write the data into the current page first. If there is insufficient space, one or more new pages are allocated as needed, and the remaining data is copied into them.
Sourcepub fn copy_to(&self, pages: &mut BytePages)
pub fn copy_to(&self, pages: &mut BytePages)
Copies all pages into another BytePages instance.
Depending on the underlying storage, this operation might be O(1) or could
involve a memory copy.
Sourcepub fn move_to(&mut self, pages: &mut BytePages)
pub fn move_to(&mut self, pages: &mut BytePages)
Moves all pages to another BytePages instance.
Sourcepub fn split_to(&mut self, at: usize) -> BytePages ⓘ
pub fn split_to(&mut self, at: usize) -> BytePages ⓘ
Splits the buffer into two at the given index.
Afterwards, self contains elements [at, len), and the returned BytePage
contains elements [0, at).
Depending on the underlying storage, this operation might be O(1) or could
involve a memory copy.
Sourcepub fn split_into(&mut self, at: usize, to: &mut BytePages)
pub fn split_into(&mut self, at: usize, to: &mut BytePages)
Splits the buffer, adding the resulting items to the supplied pages object.
Afterwards, self contains elements [at, len), and the supplied BytePage
contains elements [0, at).
Depending on the underlying storage, this operation might be O(1) or could
involve a memory copy.
pub fn try_get_current_from(&mut self, pages: &mut BytePages)
Sourcepub fn with_bytes_mut<F, R>(&mut self, f: F) -> R
pub fn with_bytes_mut<F, R>(&mut self, f: F) -> R
Access current page as BytesMut object